README

# Scylla Stress Orchestrator

The Scylla Stress Orchestrator is Python based framework for running various benchmark 
tools including cassandra-stress and scylla-bench.

## Requirements

Scylla Stress Orchestrator requires the following tools to be installed:
- Python 3.7+
- Terraform
- Java 1.8+
- Awscli
- Openssh-client or Openssh

## Installation

To install the Scylla Stress Orchestrator

```
pip install scyllaso
```

Also set the AWS access key and secret key in either ~/.profile or in ~/.bash_profile

```
export AWS_ACCESS_KEY_ID=<access_key>
export AWS_SECRET_ACCESS_KEY=<secret_key>

```

## Creating a benchmark

A template benchmark can be generated by calling:
```
generate_benchmark foo
```
This will create a new directory `foo` with the benchmark including the EC2 configuration for
the Scylla cluster nodes, Scylla monitoring and the load generators. Checkout the README in the generated 
directory for more details.

